﻿/*
  Antenna House PDF Tool API V6.0
  .Net Interface sample program

  概要：スタンプ注釈の作成

  Copyright (C) 2018- Antenna House, Inc. All rights reserved.
  Antenna House is a trademark of [Antenna House, Inc.]

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
*/

using PdfTkNet;
using System;

namespace cookbook
{
    public class AppendAnnotStampDefault
    {
        // そのクラスのusageを表示する関数
        private static void printUsage()
        {
            Console.WriteLine("usage: AppendAnnotStampDefault in-pdf-file" +
                               " out-pdf-file スタンプ種類");
        }

        /**
         * @param args the command line arguments
         */
        public static void Main(String[] args)
        {
            if (args.Length < 3)
            {
                printUsage();
                return;
            }

            // コマンドライン引数の処理
            String stampKind = args[2];
            try
            {
                using (PtlParamInput inputFile = new PtlParamInput(args[0]))
                using (PtlParamOutput outputFile = new PtlParamOutput(args[1]))
                using (PtlPDFDocument doc = new PtlPDFDocument())
                {
                    // PDFファイルをロードします。
                    doc.load(inputFile);

                    using (PtlPages pages = doc.getPages()) //ページコンテナの取得
                    {
                      // ページコンテナが空かどうか
                        if (pages.isEmpty())
                        {
                            Console.WriteLine("ページコンテナが空\n");
                            return;
                        }

                        using (PtlPage page = pages.get(0))
                        using (PtlAnnots annots = page.getAnnots())
                        {
                            addPreDefinedStampAnnot(annots, stampKind);
                        }
                    }

                    // ファイルに保存します。
                    doc.save(outputFile);
                }
            }
            catch (PtlException pex)
            {
                Console.WriteLine("PtlException : ErrorCode = " + pex.getErrorCode() +
                                   "\n  " + pex.getErrorMessage());
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
                Console.WriteLine(ex.StackTrace);
            }
            finally
            {
                Console.WriteLine("-- 完了 --");
            }
        }

        public static void addPreDefinedStampAnnot(PtlAnnots annots, String stampKind)
        {
            using (PtlAnnotStamp stampAnnot1 = new PtlAnnotStamp())
            using (PtlRect rect = new PtlRect(10.0f, 270.0f, 60.0f, 290.0f))
            {
                stampAnnot1.setRect(rect);
                stampAnnot1.setIconType((PtlAnnotStamp.ICON_TYPE)Enum.Parse(typeof(PtlAnnotStamp.ICON_TYPE), stampKind));
                stampAnnot1.setAnnotFlags(PtlAnnot.ANNOT_FLAGS.FLAG_PRINT);
                annots.append(stampAnnot1);
            }
        }

    }
}
